About OMEGAlpes
===============

A detailed presentation of OMEGAlpes in the PhD report of Camille Pajot is available in French here:
`OMEGAlpes Outil d'aide à la décision pour une planification énergétique multi-fluides optimale à l'échelle des quartiers`_,
or in English in the following article: `An Optimization Modeler as an Efficient Tool for Design and Operation for City Energy Stakeholders and Decision Makers`_

OMEGAlpes is a linear optimization tool designed to easily generate multi-carrier energy system models. Its purpose is to assist in developing district energy projects by integrating design and operation in pre-studies phases.
OMEGAlpes is open-source and written in Python with the licence `Apache 2.0`_.
It is a generation model tool based on an intuitive and extensible object-oriented library that aims to provide a panel of pre-built energy units with predefined operational options, and associated constraints and objectives taking into account stakeholders.

OMEGAlpes is developed in order to provide various features regarding energy system optimization, and especially energy flexibility:
.. toctree::
   :maxdepth: 2

   api/flexibility

.. _OMEGAlpes Outil d'aide à la décision pour une planification énergétique multi-fluides optimale à l'échelle des quartiers: https://www.theses.fr/s162247
.. _An Optimization Modeler as an Efficient Tool for Design and Operation for City Energy Stakeholders and Decision Makers: https://hal.archives-ouvertes.fr/hal-02285954
.. _`Apache 2.0`: https://www.apache.org/licenses/LICENSE-2.0.html
